==> switchyard-test-0.1.0-sources.jar: org/switchyard/test/SimpleTestDeployment.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */

package org.switchyard.test;

import org.switchyard.ServiceDomain;
import org.switchyard.deploy.internal.AbstractDeployment;

/**
 * Simple Test Deployment.
 * <p/>
 * Does nothing extra.
 *
 * @author <a href="mailto:tom.fennelly@gmail.com">tom.fennelly@gmail.com</a>
 */
public class SimpleTestDeployment extends AbstractDeployment {

    /**
     * Constructor.
     *
     */
    protected SimpleTestDeployment() {
        super(null);
    }

    @Override
    /*
     * Init method.
     * 
     * @param serviceDomain The ServiceDomain that the deployment is a member of.
     */
    public void init(ServiceDomain serviceDomain) {
        super.init(serviceDomain);
    }

    @Override
    public void start() {
    }

    @Override
    public void stop() {
    }

    @Override
    public void destroy() {
    }
}

==> switchyard-test-0.3.0-20111129.190454-21-sources.jar: org/switchyard/test/SimpleTestDeployment.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */

package org.switchyard.test;

import java.util.List;

import org.switchyard.deploy.Activator;
import org.switchyard.deploy.internal.AbstractDeployment;

/**
 * Simple Test Deployment.
 * <p/>
 * Does nothing extra.
 *
 * @author <a href="mailto:tom.fennelly@gmail.com">tom.fennelly@gmail.com</a>
 */
public class SimpleTestDeployment extends AbstractDeployment {

    /**
     * Constructor.
     *
     */
    protected SimpleTestDeployment() {
        super(null);
    }

    @Override
    /*
     * Init method.
     * 
     * @param serviceDomain The ServiceDomain that the deployment is a member of.
     */
    protected void doInit(List<Activator> activators) {
    }

    @Override
    protected void doStart() {
    }

    @Override
    protected void doStop() {
    }

    @Override
    protected void doDestroy() {
    }
}
